==> libcamera-docs-0.1.0-2-aarch64.pkg.tar.xz: usr/share/doc/libcamera/api-html/search/functions_1.js <==
var searchData=
[
  ['abs_5fdiff_0',['abs_diff',['../utils_8h.html#ac32a1f64e6a68944b89779c4bbe895e7',1,'libcamera::utils']]],
  ['acquire_1',['acquire',['../classlibcamera_1_1Camera.html#a4e60f8015f64e5897394d6677e3fb274',1,'libcamera::Camera::acquire()'],['../classlibcamera_1_1Semaphore.html#a60abc22a4c25592ec6c78cd888eeb8a9',1,'libcamera::Semaphore::acquire()'],['../classlibcamera_1_1PipelineHandler.html#a204ba8d740dde4a755392b0db2715b9c',1,'libcamera::PipelineHandler::acquire()'],['../classlibcamera_1_1MediaDevice.html#a02fd5f5a3d81330a87f1ee53511866ef',1,'libcamera::MediaDevice::acquire()']]],
  ['acquiremediadevice_2',['acquireMediaDevice',['../classlibcamera_1_1PipelineHandler.html#a77e424fe704e7b26094164b9189e0f84',1,'libcamera::PipelineHandler']]],
  ['add_3',['add',['../classlibcamera_1_1DeviceMatch.html#acf0e970d41842da73e1ee25bfb24de3a',1,'libcamera::DeviceMatch']]],
  ['addbuffer_4',['addBuffer',['../classlibcamera_1_1Request.html#a470cae8064c46e66367ea236dc13287d',1,'libcamera::Request']]],
  ['addconfiguration_5',['addConfiguration',['../classlibcamera_1_1CameraConfiguration.html#aa06a84e7e133269f226a9b2016f08401',1,'libcamera::CameraConfiguration']]],
  ['adddevice_6',['addDevice',['../classlibcamera_1_1DeviceEnumerator.html#a1e618229382268ba6ef0a559afaa51cf',1,'libcamera::DeviceEnumerator']]],
  ['addlink_7',['addLink',['../classlibcamera_1_1MediaPad.html#a2f92b90894f68e56cd94270a315c3305',1,'libcamera::MediaPad']]],
  ['adjust_8',['adjust',['../classlibcamera_1_1ColorSpace.html#ad377f24ac0123bff0d12eb77a0c6e169',1,'libcamera::ColorSpace']]],
  ['algorithmfactory_9',['AlgorithmFactory',['../classlibcamera_1_1ipa_1_1AlgorithmFactory.html#aa5eff7bc2aa30091370eddc6d67e00bc',1,'libcamera::ipa::AlgorithmFactory']]],
  ['algorithms_10',['algorithms',['../classlibcamera_1_1ipa_1_1Module.html#a99862ac2546d99418f1ac826af38c32a',1,'libcamera::ipa::Module']]],
  ['aligndown_11',['alignDown',['../utils_8h.html#a2950834476fdd93908c4a275edccac4a',1,'libcamera::utils']]],
  ['aligndownto_12',['alignDownTo',['../classlibcamera_1_1Size.html#a62029f2581ed8a885bef2757ab180c04',1,'libcamera::Size']]],
  ['aligneddownto_13',['alignedDownTo',['../classlibcamera_1_1Size.html#a4fa3aa5072c30edcff35b2a6dd795f35',1,'libcamera::Size']]],
  ['alignedupto_14',['alignedUpTo',['../classlibcamera_1_1Size.html#add28099d27d7dfaa786383b5e4c3b11a',1,'libcamera::Size']]],
  ['alignup_15',['alignUp',['../utils_8h.html#a973e18b140de0499255673e3a2f4d861',1,'libcamera::utils']]],
  ['alignupto_16',['alignUpTo',['../classlibcamera_1_1Size.html#a2488b808661172107f34afadc346c674',1,'libcamera::Size']]],
  ['alloc_17',['alloc',['../classlibcamera_1_1ipa_1_1FCQueue.html#a30a8f9b03de53964effa77b76aeef6e5',1,'libcamera::ipa::FCQueue']]],
  ['allocate_18',['allocate',['../classlibcamera_1_1FrameBufferAllocator.html#a1d115534f49614e3466f5e86fbc43f2a',1,'libcamera::FrameBufferAllocator']]],
  ['allocatebuffers_19',['allocateBuffers',['../classlibcamera_1_1V4L2VideoDevice.html#a25c378ab5d8ab5cb14b06d1981e032ed',1,'libcamera::V4L2VideoDevice']]],
  ['allocated_20',['allocated',['../classlibcamera_1_1FrameBufferAllocator.html#a9931b9d499b2d72287129aaa0d6f9fd7',1,'libcamera::FrameBufferAllocator']]],
  ['ancillaryentities_21',['ancillaryEntities',['../classlibcamera_1_1MediaEntity.html#a801eb7c5ad38c31e540925766d8b1c44',1,'libcamera::MediaEntity']]],
  ['applycontrols_22',['applyControls',['../classlibcamera_1_1DelayedControls.html#a87b491f735cbf0473111edded25fe897',1,'libcamera::DelayedControls']]],
  ['asdict_23',['asDict',['../classlibcamera_1_1YamlObject.html#aa13714170163aa9d2325aa4847f28247',1,'libcamera::YamlObject']]],
  ['aslist_24',['asList',['../classlibcamera_1_1YamlObject.html#afda1fc710962215ea21fe6b4f8d584ae',1,'libcamera::YamlObject']]],
  ['at_25',['at',['../classlibcamera_1_1CameraConfiguration.html#a41dfacc5c5d6550299fa2759792734e5',1,'libcamera::CameraConfiguration::at(unsigned int index)'],['../classlibcamera_1_1CameraConfiguration.html#a9264605146b5d955f987546b18133e60',1,'libcamera::CameraConfiguration::at(unsigned int index) const'],['../classlibcamera_1_1ControlInfoMap.html#a057114f670890807ac4b09a1e3f6c300',1,'libcamera::ControlInfoMap::at(unsigned int key)'],['../classlibcamera_1_1ControlInfoMap.html#a719aacd65be3619a0c03db40c4c2452f',1,'libcamera::ControlInfoMap::at(unsigned int key) const']]],
  ['available_26',['available',['../classlibcamera_1_1Semaphore.html#a6f7388c198b17adfd0bcde0368d0c29c',1,'libcamera::Semaphore']]]
];

==> libcamera-docs-0.2.0-1-aarch64.pkg.tar.xz: usr/share/doc/libcamera/api-html/search/functions_1.js <==
var searchData=
[
  ['abs_5fdiff_0',['abs_diff',['../utils_8h.html#ac32a1f64e6a68944b89779c4bbe895e7',1,'libcamera::utils']]],
  ['acquire_1',['acquire',['../classlibcamera_1_1Semaphore.html#a60abc22a4c25592ec6c78cd888eeb8a9',1,'libcamera::Semaphore::acquire()'],['../classlibcamera_1_1Camera.html#a4e60f8015f64e5897394d6677e3fb274',1,'libcamera::Camera::acquire()'],['../classlibcamera_1_1MediaDevice.html#a02fd5f5a3d81330a87f1ee53511866ef',1,'libcamera::MediaDevice::acquire()'],['../classlibcamera_1_1PipelineHandler.html#a204ba8d740dde4a755392b0db2715b9c',1,'libcamera::PipelineHandler::acquire()']]],
  ['acquiremediadevice_2',['acquireMediaDevice',['../classlibcamera_1_1PipelineHandler.html#a77e424fe704e7b26094164b9189e0f84',1,'libcamera::PipelineHandler']]],
  ['add_3',['add',['../classlibcamera_1_1DeviceMatch.html#acf0e970d41842da73e1ee25bfb24de3a',1,'libcamera::DeviceMatch']]],
  ['addbuffer_4',['addBuffer',['../classlibcamera_1_1Request.html#a470cae8064c46e66367ea236dc13287d',1,'libcamera::Request']]],
  ['addconfiguration_5',['addConfiguration',['../classlibcamera_1_1CameraConfiguration.html#aa06a84e7e133269f226a9b2016f08401',1,'libcamera::CameraConfiguration']]],
  ['adddevice_6',['addDevice',['../classlibcamera_1_1DeviceEnumerator.html#a1e618229382268ba6ef0a559afaa51cf',1,'libcamera::DeviceEnumerator']]],
  ['addlink_7',['addLink',['../classlibcamera_1_1MediaPad.html#a2f92b90894f68e56cd94270a315c3305',1,'libcamera::MediaPad']]],
  ['adjust_8',['adjust',['../classlibcamera_1_1ColorSpace.html#ad377f24ac0123bff0d12eb77a0c6e169',1,'libcamera::ColorSpace']]],
  ['algorithmfactory_9',['AlgorithmFactory',['../classlibcamera_1_1ipa_1_1AlgorithmFactory.html#aa5eff7bc2aa30091370eddc6d67e00bc',1,'libcamera::ipa::AlgorithmFactory']]],
  ['algorithms_10',['algorithms',['../classlibcamera_1_1ipa_1_1Module.html#a99862ac2546d99418f1ac826af38c32a',1,'libcamera::ipa::Module']]],
  ['aligndown_11',['alignDown',['../utils_8h.html#a2950834476fdd93908c4a275edccac4a',1,'libcamera::utils']]],
  ['aligndownto_12',['alignDownTo',['../classlibcamera_1_1Size.html#a62029f2581ed8a885bef2757ab180c04',1,'libcamera::Size']]],
  ['aligneddownto_13',['alignedDownTo',['../classlibcamera_1_1Size.html#a4fa3aa5072c30edcff35b2a6dd795f35',1,'libcamera::Size']]],
  ['alignedupto_14',['alignedUpTo',['../classlibcamera_1_1Size.html#add28099d27d7dfaa786383b5e4c3b11a',1,'libcamera::Size']]],
  ['alignup_15',['alignUp',['../utils_8h.html#a973e18b140de0499255673e3a2f4d861',1,'libcamera::utils']]],
  ['alignupto_16',['alignUpTo',['../classlibcamera_1_1Size.html#a2488b808661172107f34afadc346c674',1,'libcamera::Size']]],
  ['alloc_17',['alloc',['../classlibcamera_1_1ipa_1_1FCQueue.html#a30a8f9b03de53964effa77b76aeef6e5',1,'libcamera::ipa::FCQueue']]],
  ['allocate_18',['allocate',['../classlibcamera_1_1FrameBufferAllocator.html#a1d115534f49614e3466f5e86fbc43f2a',1,'libcamera::FrameBufferAllocator']]],
  ['allocatebuffers_19',['allocateBuffers',['../classlibcamera_1_1V4L2VideoDevice.html#a25c378ab5d8ab5cb14b06d1981e032ed',1,'libcamera::V4L2VideoDevice']]],
  ['allocated_20',['allocated',['../classlibcamera_1_1FrameBufferAllocator.html#a9931b9d499b2d72287129aaa0d6f9fd7',1,'libcamera::FrameBufferAllocator']]],
  ['ancillaryentities_21',['ancillaryEntities',['../classlibcamera_1_1MediaEntity.html#a801eb7c5ad38c31e540925766d8b1c44',1,'libcamera::MediaEntity']]],
  ['applyconfiguration_22',['applyConfiguration',['../classlibcamera_1_1CameraSensor.html#a74d7273dd54bd297b11e46c1d803f593',1,'libcamera::CameraSensor']]],
  ['applycontrols_23',['applyControls',['../classlibcamera_1_1DelayedControls.html#a87b491f735cbf0473111edded25fe897',1,'libcamera::DelayedControls']]],
  ['asdict_24',['asDict',['../classlibcamera_1_1YamlObject.html#aa13714170163aa9d2325aa4847f28247',1,'libcamera::YamlObject']]],
  ['aslist_25',['asList',['../classlibcamera_1_1YamlObject.html#afda1fc710962215ea21fe6b4f8d584ae',1,'libcamera::YamlObject']]],
  ['at_26',['at',['../classlibcamera_1_1CameraConfiguration.html#a41dfacc5c5d6550299fa2759792734e5',1,'libcamera::CameraConfiguration::at(unsigned int index)'],['../classlibcamera_1_1CameraConfiguration.html#a9264605146b5d955f987546b18133e60',1,'libcamera::CameraConfiguration::at(unsigned int index) const'],['../classlibcamera_1_1ControlInfoMap.html#a057114f670890807ac4b09a1e3f6c300',1,'libcamera::ControlInfoMap::at(unsigned int key)'],['../classlibcamera_1_1ControlInfoMap.html#a719aacd65be3619a0c03db40c4c2452f',1,'libcamera::ControlInfoMap::at(unsigned int key) const']]],
  ['available_27',['available',['../classlibcamera_1_1Semaphore.html#a6f7388c198b17adfd0bcde0368d0c29c',1,'libcamera::Semaphore']]]
];
